# Generated by Django 4.0.4 on 2022-05-16 19:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0001_squashed_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='card',
            name='first_digits',
            field=models.CharField(blank=True, max_length=6),
        ),
        migrations.AddField(
            model_name='card',
            name='name',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='phone_number',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='postal_code',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='state',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='street1',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='street2',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AddField(
            model_name='card',
            name='tokenization_method',
            field=models.CharField(blank=True, max_length=255),
        ),
    ]



from django.db import models
from django.utils.translation import gettext_lazy as _

class ChargeStatus(models.TextChoices):
    FAILED = "failed", _("Failed")
    EXPIRED = "expired", _("Expired")
    PENDING = "pending", _("Pending")
    REVERSED = "reverse", _("Reversed")
    SUCCESSFUL = "successful", _("Successful")
    UNKNOWN = "unknown", _("Unknown")

class Currency(models.TextChoices):
    USD = (
        "USD",
        _("United States Dollar"),
    )
    THB = (
        "THB",
        _("Thai Baht"),
    )
    SGD = (
        "SGD",
        _("Singapore Dollar"),
    )
    JPY = (
        "JPY",
        _("Japanese Yen"),
    )
    GBP = (
        "GBP",
        _("Pound Sterling"),
    )
    EUR = (
        "EUR",
        _("Euro"),
    )
    CNY = (
        "CNY",
        _("Chinese Yuan"),
    )
    AUD = (
        "AUD",
        _("Australian Dollar"),
    )
